summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/msn/msnswitchboardsocket.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/protocols/msn/msnswitchboardsocket.cpp
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/msn/msnswitchboardsocket.cpp')
-rw-r--r--kopete/protocols/msn/msnswitchboardsocket.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/protocols/msn/msnswitchboardsocket.cpp b/kopete/protocols/msn/msnswitchboardsocket.cpp
index f5cc890a..319df782 100644
--- a/kopete/protocols/msn/msnswitchboardsocket.cpp
+++ b/kopete/protocols/msn/msnswitchboardsocket.cpp
@@ -63,8 +63,8 @@
#include "dispatcher.h"
using P2P::Dispatcher;
-MSNSwitchBoardSocket::MSNSwitchBoardSocket( MSNAccount *account , TQObject *tqparent )
-: MSNSocket( tqparent )
+MSNSwitchBoardSocket::MSNSwitchBoardSocket( MSNAccount *account , TQObject *parent )
+: MSNSocket( parent )
{
m_account = account;
m_recvIcons=0;
@@ -767,7 +767,7 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
int nb=(int)ceil((float)(len_M)/(float)(futurmessages_size));
- if(KMessageBox::warningContinueCancel(0L /* FIXME: we should try to find a tqparent somewere*/ ,
+ if(KMessageBox::warningContinueCancel(0L /* FIXME: we should try to find a parent somewere*/ ,
i18n("The message you are trying to send is too long; it will be split into %1 messages.").tqarg(nb) ,
i18n("Message too big - MSN Plugin" ), KStdGuiItem::cont() , "SendLongMessages" )
== KMessageBox::Continue )
@@ -1104,7 +1104,7 @@ void MSNSwitchBoardSocket::slotKeepAliveTimer( )
{
/*
This is a workaround against the bug 113425
- The problem: the P2P::Webcam class is tqparent of us, and when we get deleted, it get deleted.
+ The problem: the P2P::Webcam class is parent of us, and when we get deleted, it get deleted.
the correct solution would be to change that.
The second problem: after one minute of inactivity, the official client close the chat socket.
the workaround: we simulate the activity by sending small packet each 50 seconds